==> pymdown-extensions-1.0.1.tar.gz: pymdown-extensions-1.0.1/README.md <==
[![Unix Build Status][travis-image]][travis-link]
[![Coverage Status][codecov-image]][codecov-link]
[![Code Health][landscape-image]][landscape-link]
[![Requirements Status][requires-image]][requires-link]
[![pypi-version][pypi-image]][pypi-link]
![License][license-image-mit]
![License][license-image-bsd]
# PyMdown Extra Extensions
Extensions for [Python Markdown](https://pythonhosted.org/Markdown/).  Written for the [PyMdown project](https://github.com/facelessuser/PyMdown).

# Documentation
Extension documentation is found at the PyMdown site: http://facelessuser.github.io/pymdown-extensions/.

# License
License is MIT except for a few exceptions that are licensed as BSD.  See LICENSE for more info.

[codecov-image]: https://img.shields.io/codecov/c/github/facelessuser/pymdown-extensions/master.svg
[codecov-link]: https://codecov.io/github/facelessuser/pymdown-extensions
[travis-image]: https://img.shields.io/travis/facelessuser/pymdown-extensions/master.svg?label=Unix%20Build
[travis-link]: https://travis-ci.org/facelessuser/pymdown-extensions
[landscape-image]: https://landscape.io/github/facelessuser/pymdown-extensions/master/landscape.svg?style=flat
[landscape-link]: https://landscape.io/github/facelessuser/pymdown-extensions/master
[requires-image]: https://img.shields.io/requires/github/facelessuser/pymdown-extensions/master.svg
[requires-link]: https://requires.io/github/facelessuser/pymdown-extensions/requirements/?branch=master
[pypi-image]: https://img.shields.io/pypi/v/pymdown-extensions.svg
[pypi-link]: https://pypi.python.org/pypi/pymdown-extensions
[license-image-mit]: https://img.shields.io/badge/license-MIT-blue.svg
[license-image-bsd]: https://img.shields.io/badge/license-BSD-blue.svg

==> pymdown-extensions-1.2.tar.gz: pymdown-extensions-1.2/README.md <==
[![Unix Build Status][travis-image]][travis-link]
[![Coverage Status][codecov-image]][codecov-link]
[![Code Health][landscape-image]][landscape-link]
[![Requirements Status][requires-image]][requires-link]
[![pypi-version][pypi-image]][pypi-link]
![License][license-image-mit]
![License][license-image-bsd]
# PyMdown Extra Extensions
Extensions for [Python Markdown](https://pythonhosted.org/Markdown/).

# Documentation
Extension documentation is found at the PyMdown site: http://facelessuser.github.io/pymdown-extensions/.

# License
License is MIT except for a few exceptions that are licensed as BSD.  See LICENSE for more info.

[codecov-image]: https://img.shields.io/codecov/c/github/facelessuser/pymdown-extensions/master.svg
[codecov-link]: https://codecov.io/github/facelessuser/pymdown-extensions
[travis-image]: https://img.shields.io/travis/facelessuser/pymdown-extensions/master.svg?label=Unix%20Build
[travis-link]: https://travis-ci.org/facelessuser/pymdown-extensions
[landscape-image]: https://landscape.io/github/facelessuser/pymdown-extensions/master/landscape.svg?style=flat
[landscape-link]: https://landscape.io/github/facelessuser/pymdown-extensions/master
[requires-image]: https://img.shields.io/requires/github/facelessuser/pymdown-extensions/master.svg
[requires-link]: https://requires.io/github/facelessuser/pymdown-extensions/requirements/?branch=master
[pypi-image]: https://img.shields.io/pypi/v/pymdown-extensions.svg
[pypi-link]: https://pypi.python.org/pypi/pymdown-extensions
[license-image-mit]: https://img.shields.io/badge/license-MIT-blue.svg
[license-image-bsd]: https://img.shields.io/badge/license-BSD-blue.svg
